@@ -1,9 +1,10 @@
 from reason.tokenize import word_tokenize
-from ._tagger import BaseTagger
+
 from ._default import DefaultTagger
-from ._regex import RegexTagger
 from ._lookup import LookupTagger
-from ._pos_tagger_data import get_re_collection, get_freq_1000
+from ._pos_tagger_data import get_freq_1000, get_re_collection
+from ._regex import RegexTagger
+from ._tagger import BaseTagger
 
 
 class POSTagger(BaseTagger):
@@ -33,16 +34,15 @@ class POSTagger(BaseTagger):
         """
         super().__init__(backoff)
 
-        default_tagger = DefaultTagger('NN')
+        default_tagger = DefaultTagger("NN")
         re_collection = get_re_collection()
         regex_tagger = RegexTagger(re_collection, backoff=default_tagger)
         lookup_data = get_freq_1000()
         lookup_tagger = LookupTagger(lookup_data, backoff=regex_tagger)
         self._tagger = lookup_tagger
 
-
     def _token_tag(self, token):
-        if word_tokenize(token, 'alphanumeric') != []:
+        if word_tokenize(token, "alphanumeric"):
             return self._tagger.tag(token)[0][1]
 
         return token
